﻿using ProjectTank.Entities;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace ProjectTank.Drawning
{
    public static class ExtensionDrawningTank
    {
        /// <summary>
        /// Разделитель для записи информации по объекту в файл
        /// </summary>
        private static readonly string _separatorForObject = ":";

        /// <summary>
        /// Создание объекта из строки
        /// </summary>
        /// <param name="info">Строка с данными для создания объекта</param>
        /// <returns>Объект</returns>
        public static DrawningTank? CreateDrawningTank(this string info)
        {
            string[] strs = info.Split(_separatorForObject);

            EntityTank? tank = EntityBattleTank.CreateEntityBattleTank(strs);
            if (tank != null)
            {
                return new DrawningBattleTank((EntityBattleTank)tank);
            }

            tank = EntityTank.CreateEntityTank(strs);
            if (tank != null)
            {
                return new DrawningTank(tank);
            }

            return null;
        }

        /// <summary>
        /// Получение данных для сохранения в файл
        /// </summary>
        /// <param name="drawningAirbus">Сохраняемый объект</param>
        /// <returns>Строка с данными по объекту</returns>
        public static string GetDataForSave(this DrawningTank drawningTank)
        {
            string[]? array = drawningTank?.EntityTank?.GetStringRepresentation();

            if (array == null)
            {
                return string.Empty;
            }

            return string.Join(_separatorForObject, array);
        }
    }
}
