﻿using ProjectTank.Entities;

namespace ProjectTank
{
    /// <summary>
    /// Класс-сущность танк
    /// </summary>
    public class EntityBattleTank : EntityTank

    {
        /// <summary>
        /// Дополнительный цвет (для опциональных элементов)
        /// </summary>
        public Color AdditionalColor { get; private set; }

        /// <summary>
        /// Признак (опция) наличия пушки 
        /// </summary>
        public bool Gun { get; private set; }


        /// <summary>
        /// Признак (опция) наличия Пулемета на башне
        /// /// </summary>
        public bool MachinGun { get; private set; }

        public void SetAdditionalColor(Color addColor)
        {
            AdditionalColor = addColor;
        }

        /// <summary>
        /// Конструктор объекта-класса Боевого Танка
        /// </summary>
        /// <param name="speed">Скорость</param>
        /// <param name="weight">Вес</param>
        /// <param name="bodyColor">Основной цвет</param>
        /// <param name="additionalColor">Дополнительный цвет</param>
        /// <param name="gun">Пушка танка</param>
        /// <param name="machinGun">Пклемет на башне</param>
        public EntityBattleTank(int speed, double weight, Color bodyColor, Color additionalColor, bool gun, bool machinGun) : base(speed, weight, bodyColor)
        {
            AdditionalColor = additionalColor;
            MachinGun= machinGun;
            Gun = gun;
        }
        /// <summary>
        /// Получение строк со значениями свойств объекта продвинутого класса-сущности
        /// </summary>
        /// <returns></returns>
        public override string[] GetStringRepresentation()
        {
            return new[] { nameof(EntityBattleTank), Speed.ToString(), Weight.ToString(), BodyColor.Name,
            AdditionalColor.Name, Gun.ToString(), MachinGun.ToString() };
        }

        /// <summary>
        /// Создание продвинутого объекта из массива строк
        /// </summary>
        /// <param name="strs"></param>
        /// <returns></returns>
        public static EntityTank? CreateEntityBattleTank(string[] strs)
        {
            if (strs.Length != 7 || strs[0] != nameof(EntityBattleTank))
            {
                return null;
            }

            return new EntityBattleTank(Convert.ToInt32(strs[1]), Convert.ToDouble(strs[2]), Color.FromName(strs[3]),
                Color.FromName(strs[4]), Convert.ToBoolean(strs[5]), Convert.ToBoolean(strs[6]));
        }
    }
}
